==> hogql_parser-0.1.8.tar.gz: hogql_parser-0.1.8/string.cpp <==
#include <boost/algorithm/string.hpp>

#include "error.h"
#include "string.h"

using namespace std;

string unquote_string(string text) {
  size_t original_text_size = text.size();
  if (original_text_size == 0) {
    throw HogQLParsingException("Encountered an unexpected empty string input");
  }
  const char first_char = text.front();
  const char last_char = text.back();
  if (first_char == '\'' && last_char == '\'') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "''", "'");
    boost::replace_all(text, "\\'", "'");
  } else if (first_char == '"' && last_char == '"') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "\"\"", "\"");
    boost::replace_all(text, "\\\"", "\"");
  } else if (first_char == '`' && last_char == '`') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "``", "`");
    boost::replace_all(text, "\\`", "`");
  } else if (first_char == '{' && last_char == '}') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "{{", "{");
    boost::replace_all(text, "\\{", "{");
  } else {
    throw HogQLSyntaxException("Invalid string literal, must start and end with the same quote type: " + text);
  }

  // Copied from clickhouse_driver/util/escape.py
  boost::replace_all(text, "\\a", "\a");
  boost::replace_all(text, "\\b", "\b");
  boost::replace_all(text, "\\f", "\f");
  boost::replace_all(text, "\\n", "\n");
  boost::replace_all(text, "\\r", "\r");
  boost::replace_all(text, "\\t", "\t");
  boost::replace_all(text, "\\v", "\v");
  boost::replace_all(text, "\\0", ""); // NUL characters are ignored
  boost::replace_all(text, "\\\\", "\\");

  return text;
}

string unquote_string_terminal(antlr4::tree::TerminalNode* node) {
  string text = node->getText();
  try {
    return unquote_string(text);
  } catch (HogQLException& e) {
    throw HogQLSyntaxException(e.what(), node->getSymbol()->getStartIndex(), node->getSymbol()->getStopIndex() + 1);
  }
}

==> hogql_parser-1.0.0.tar.gz: hogql_parser-1.0.0/string.cpp <==
#include <boost/algorithm/string.hpp>

#include "error.h"
#include "string.h"

using namespace std;

string unquote_string(string text) {
  size_t original_text_size = text.size();
  if (original_text_size == 0) {
    throw ParsingException("Encountered an unexpected empty string input");
  }
  const char first_char = text.front();
  const char last_char = text.back();
  if (first_char == '\'' && last_char == '\'') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "''", "'");
    boost::replace_all(text, "\\'", "'");
  } else if (first_char == '"' && last_char == '"') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "\"\"", "\"");
    boost::replace_all(text, "\\\"", "\"");
  } else if (first_char == '`' && last_char == '`') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "``", "`");
    boost::replace_all(text, "\\`", "`");
  } else if (first_char == '{' && last_char == '}') {
    text = text.substr(1, original_text_size - 2);
    boost::replace_all(text, "{{", "{");
    boost::replace_all(text, "\\{", "{");
  } else {
    throw SyntaxException("Invalid string literal, must start and end with the same quote type: " + text);
  }

  // Copied from clickhouse_driver/util/escape.py
  boost::replace_all(text, "\\a", "\a");
  boost::replace_all(text, "\\b", "\b");
  boost::replace_all(text, "\\f", "\f");
  boost::replace_all(text, "\\n", "\n");
  boost::replace_all(text, "\\r", "\r");
  boost::replace_all(text, "\\t", "\t");
  boost::replace_all(text, "\\v", "\v");
  boost::replace_all(text, "\\0", ""); // NUL characters are ignored
  boost::replace_all(text, "\\\\", "\\");

  return text;
}

string unquote_string_terminal(antlr4::tree::TerminalNode* node) {
  string text = node->getText();
  try {
    return unquote_string(text);
  } catch (SyntaxException& e) {
    throw SyntaxException(e.what(), node->getSymbol()->getStartIndex(), node->getSymbol()->getStopIndex() + 1);
  } catch (ParsingException& e) {
    throw ParsingException(e.what(), node->getSymbol()->getStartIndex(), node->getSymbol()->getStopIndex() + 1);
  }
}
